Learn R Programming

scDECO (version 0.1.1)

scdeco.pg.xc: ZENCO fitting function when secondary covariate is provided

Description

ZENCO fitting function when secondary covariate is provided

Usage

scdeco.pg.xc(
  dat,
  b0,
  b1,
  adapt_iter = 10000,
  update_iter = 5000,
  coda_iter = 50000,
  coda_thin = 20,
  coda_burnin = 10000
)

Value

MCMC samples that have been adapted, burned, and thinned

Arguments

dat

matrix containing expression values as first two columns and covariate as third column

b0

intercept of zinf parameter

b1

slope of zinf parameter

adapt_iter

number of adaptation iterations in the jags.model function

update_iter

update iterations in the update function

coda_iter

number of iterations for the coda.sample function

coda_thin

how much to thin the resulting MCMC output

coda_burnin

how many iterations to burn before beginning coda sample collection