ZENCO fitting function when secondary covariate is provided
scdeco.pg.xc(
dat,
b0,
b1,
adapt_iter = 10000,
update_iter = 5000,
coda_iter = 50000,
coda_thin = 20,
coda_burnin = 10000
)MCMC samples that have been adapted, burned, and thinned
matrix containing expression values as first two columns and covariate as third column
intercept of zinf parameter
slope of zinf parameter
number of adaptation iterations in the jags.model function
update iterations in the update function
number of iterations for the coda.sample function
how much to thin the resulting MCMC output
how many iterations to burn before beginning coda sample collection